package com.aiqu.demo;

import android.Manifest;
import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
import com.wancms.sdk.WancmsSDKManager;
import com.wancms.sdk.domain.LoginErrorMsg;
import com.wancms.sdk.domain.LogincallBack;
import com.wancms.sdk.domain.LogoutErrorMsg;
import com.wancms.sdk.domain.LogoutcallBack;
import com.wancms.sdk.domain.OnLoginListener;
import com.wancms.sdk.domain.OnLogoutListener;
import com.wancms.sdk.domain.OnPaymentListener;
import com.wancms.sdk.domain.PaymentCallbackInfo;
import com.wancms.sdk.domain.PaymentErrorMsg;
import com.wancms.sdk.domain.PermissionListener;
import com.wancms.sdk.ui.BaseActivity;
import com.wancms.sdk.util.DialogUtil;
import com.wancms.sdk.util.Logger;
import com.wancms.sdk.util.Md5Util;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.List;

public class MainActivity extends BaseActivity implements OnClickListener {
	private EditText et_money;
	private Button btn_login, btn_charger, btn_role, btn_logout;
	private long exitTime = 0;
	private boolean isAgreeAgreement = false; //请研发自行本地缓存是否同意隐私
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.activity_main);

		WancmsSDKManager.initSdkOnCreateFirst(MainActivity.this);

		btn_login = findViewById(R.id.btn_login);
		btn_charger = findViewById(R.id.btn_charger);
		btn_logout = findViewById(R.id.btn_logout);
		et_money = findViewById(R.id.et_money);
		btn_role = findViewById(R.id.btn_role);

		btn_role.setOnClickListener(this);
		btn_login.setOnClickListener(this);
		btn_charger.setOnClickListener(this);
		btn_logout.setOnClickListener(this);

		if (!isAgreeAgreement){
			showAgreementView();
		}
	}

	private void showAgreementView(){
		DialogUtil.popAgreementView(mContext, new DialogUtil.AgreeCallback() {
			@Override
			public void onAgree() {
				isAgreeAgreement = true;
			}
		});
	}


	@Override
	public void onClick(final View v) {
		if (isAgreeAgreement){
			dealClickEvent(v);
		}else {
			Toast.makeText(getApplication(), "请先同意用户协议",
					Toast.LENGTH_LONG).show();
		}
	}



	private void dealClickEvent(View v){
		if (null != btn_login && btn_login.getId() == v.getId()) { // 点击登录按钮  请研发先申请 WRITE_EXTERNAL_STORAGE，READ_PHONE_STATE两个权限
			doLogin();
		}

		if (null != btn_charger && btn_charger.getId() == v.getId()) { // 点击登录按钮
			doCharge();
		}

		if (btn_role != null && btn_role.getId() == v.getId()) {
			try {
				JSONObject json = new JSONObject();
				json.put("time", "20170417");
				WancmsSDKManager.getInstance(MainActivity.this).setRoleDate("caobawang11", "草霸王", "100",
						"1", "wancms", json);
			} catch (JSONException e) {
				e.printStackTrace();
			}
		}

		if (btn_logout != null && btn_logout.getId() == v.getId()) {
			WancmsSDKManager.getInstance(MainActivity.this).recycle();
		}
	}



	private void doLogin() {
		WancmsSDKManager.getInstance(this).showLogin(new OnLoginListener() {
			@Override
			public void loginSuccess(LogincallBack logincallback) {
				showFloatView();
				String appKey = "70047be011bfd3e933c38eb2a9344f06";  //appKey 由爱趣平台提供给研发
				String str = String.format("username=%s&appkey=%s&logintime=%s",logincallback.username,appKey,logincallback.logintime);
				String signStr = Md5Util.md5(str);
				if (signStr.equals(logincallback.sign)){
					Toast.makeText(MainActivity.this, "登录验签成功", Toast.LENGTH_LONG).show();
				}else {
					Toast.makeText(MainActivity.this, "验签失败", Toast.LENGTH_LONG).show();
				}
			}

			@Override
			public void loginError(LoginErrorMsg errorMsg) {
				Toast.makeText(getApplication(), errorMsg.msg,
						Toast.LENGTH_LONG).show();
			}
		});
	}

	private void doCharge() {
		String money_str = et_money.getText().toString().trim();
		String money = "1";
		if (!TextUtils.isEmpty(money_str) && !"".equals(money_str)) {
			money = money_str;
		}

		JSONObject jsonObject = new JSONObject();
		try {
			jsonObject.put("a", "dsd");
		} catch (JSONException e) {
			e.printStackTrace();
		}
		WancmsSDKManager.getInstance(this).showPay("caobawang158", money, "1", "杀人书",
				"金币", "cp4551223", jsonObject.toString(), new OnPaymentListener() {
					@Override
					public void paymentSuccess(PaymentCallbackInfo callbackInfo) {
						Toast.makeText(getApplication(), "充值金额数" + callbackInfo.money + " 消息提示：" + callbackInfo.msg, Toast.LENGTH_LONG).show();
					}

					@Override
					public void paymentError(PaymentErrorMsg errorMsg) {
						Toast.makeText(getApplication(), "充值失败：code:" + errorMsg.code + "  ErrorMsg:" + errorMsg.msg + "  预充值的金额：" + errorMsg.money, Toast.LENGTH_LONG).show();
					}
				});
	}

	private void showFloatView() {
		Handler handler = new Handler();
		handler.postDelayed(new Runnable() {
			@Override
			public void run() {
				WancmsSDKManager.getInstance(MainActivity.this).showFloatView(MainActivity.this, new OnLogoutListener() {
					@Override
					public void logoutSuccess(LogoutcallBack logoutncallback) {
						Toast.makeText(getApplication(), "用户" + logoutncallback.username + "退出登录", Toast.LENGTH_LONG).show();
						doLogin();
					}

					@Override
					public void logoutError(LogoutErrorMsg errorMsg) {

					}
				});
			}
		}, 1000);
	}






	@Override
	public boolean onKeyDown(int keyCode, KeyEvent event) {
		if (keyCode == KeyEvent.KEYCODE_BACK
				&& event.getAction() == KeyEvent.ACTION_DOWN) {
			if ((System.currentTimeMillis() - exitTime) > 2000) {
				Toast.makeText(getApplicationContext(), "再按一次退出程序",
						Toast.LENGTH_SHORT).show();
				exitTime = System.currentTimeMillis();
			} else {
				Logger.msg("两次返回键退出");
				WancmsSDKManager.getInstance(this).recycle();
			}
			return true;
		}
		return super.onKeyDown(keyCode, event);
	}
}
